KnobNodeBase<T> class abstract

Implementers

Constructors

KnobNodeBase({required String key, String? description, required T value})
const

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → String
no setter
title → String
no setter
value → T
final

Methods

copyWithValue({T? value}) → KnobNodeBase<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited