KnobNodeText class

Inheritance

Constructors

KnobNodeText({required String key, String? description, required String value})

Properties

description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → String
no setterinherited
title → String
no setterinherited
value → String
finalinherited

Methods

copyWithValue({String? value}) → KnobNodeBase<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited